<template>
  <div class="info-track-list">
    <div class="header">
      <div class="title">
        <span class="name">轨迹详情</span>
      </div>
    </div>
    <div class="content">
      <div class="list-header">
        <div class="col col-1">时间</div>
        <div class="col col-2">位置参数</div>
      </div>
      <van-list class="list-body">
        <van-cell class="list-row" v-for="(item, index) in data" :key="index">
          <span class="list-col list-col-1">{{ item.createdTime }}</span>
          <span class="list-col list-col-2">{{ coordinatesFormatter(item) }}</span>
        </van-cell>
      </van-list>
    </div>
  </div>
</template>

<script>
import { List, Cell } from "vant";
export default {
  name: "infoTrackList",
  components: {
    [List.name]: List,
    [Cell.name]: Cell,
  },
  props: {
    data: {
      type: Array,
      default() {
        return [];
      },
    },
  },
  computed: {
    coordinatesFormatter() {
      return function ({ longitude, latitude }) {
        return `${longitude}，${latitude}`;
      };
    },
  },
};
</script>

<style scoped lang="less">
.info-track-list {
  .header {
    width: 100%;
    height: 64px;
    background: #ffffff;
    padding: 0 20px;
    box-sizing: border-box;
    display: flex;
    align-items: center;
    //justify-content: space-between;
    .title {
      display: flex;
      align-items: center;
      .name {
        font-size: 14px;
        font-family: PingFang SC-Medium, PingFang SC, serif;
        font-weight: 500;
        color: #303133;
        line-height: 22px;
        margin-left: 8px;
      }
    }
  }
  .content {
    width: 100%;
    padding: 0 12px;
    height: calc(100vh - 64px - 44px);
    box-sizing: border-box;
    .list-header {
      width: 100%;
      height: 36px;
      background: #fafafa;
      border-radius: 4px 4px 0 0;
      border-bottom: 1px solid #c2c2c2;
      display: flex;
      .col {
        height: 100%;
        display: flex;
        align-items: center;
        justify-content: center;
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #3d3d3d;
        line-height: 22px;
        &-1 {
          width: 50%;
        }
        &-2 {
          width: 50%;
        }
      }
    }
    .list-body {
      width: 100%;
      height: calc(100% - 36px);
      overflow-x: hidden;
      overflow-y: auto;
      .list-row {
        padding: 0;
        .van-cell__value {
          display: flex;
          .list-col {
            display: flex;
            align-items: center;
            justify-content: center;
            height: 48px;
            font-size: 12px;
            font-family: PingFang SC-Regular, PingFang SC, serif;
            font-weight: 400;
            color: #3d3d3d;
            //line-height: 22px;
            &-1 {
              width: 50%;
            }
            &-2 {
              width: 50%;
            }
          }
        }
      }
    }
  }
}
</style>
